==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSmartVolumeMapper.java <==
// java wrapper for vtkSmartVolumeMapper object
//

package vtk;
import vtk.*;

public class vtkSmartVolumeMapper extends vtkVolumeMapper
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFinalColorWindow_2(double id0);
  public void SetFinalColorWindow(double id0)
    { SetFinalColorWindow_2(id0); }

  private native double GetFinalColorWindow_3();
  public double GetFinalColorWindow()
    { return GetFinalColorWindow_3(); }

  private native void SetFinalColorLevel_4(double id0);
  public void SetFinalColorLevel(double id0)
    { SetFinalColorLevel_4(id0); }

  private native double GetFinalColorLevel_5();
  public double GetFinalColorLevel()
    { return GetFinalColorLevel_5(); }

  private native void SetRequestedRenderMode_6(int id0);
  public void SetRequestedRenderMode(int id0)
    { SetRequestedRenderMode_6(id0); }

  private native void SetRequestedRenderModeToDefault_7();
  public void SetRequestedRenderModeToDefault()
    { SetRequestedRenderModeToDefault_7(); }

  private native void SetRequestedRenderModeToRayCast_8();
  public void SetRequestedRenderModeToRayCast()
    { SetRequestedRenderModeToRayCast_8(); }

  private native void SetRequestedRenderModeToGPU_9();
  public void SetRequestedRenderModeToGPU()
    { SetRequestedRenderModeToGPU_9(); }

  private native void SetRequestedRenderModeToOSPRay_10();
  public void SetRequestedRenderModeToOSPRay()
    { SetRequestedRenderModeToOSPRay_10(); }

  private native int GetRequestedRenderMode_11();
  public int GetRequestedRenderMode()
    { return GetRequestedRenderMode_11(); }

  private native int GetLastUsedRenderMode_12();
  public int GetLastUsedRenderMode()
    { return GetLastUsedRenderMode_12(); }

  private native void SetMaxMemoryInBytes_13(int id0);
  public void SetMaxMemoryInBytes(int id0)
    { SetMaxMemoryInBytes_13(id0); }

  private native int GetMaxMemoryInBytes_14();
  public int GetMaxMemoryInBytes()
    { return GetMaxMemoryInBytes_14(); }

  private native void SetMaxMemoryFraction_15(double id0);
  public void SetMaxMemoryFraction(double id0)
    { SetMaxMemoryFraction_15(id0); }

  private native double GetMaxMemoryFractionMinValue_16();
  public double GetMaxMemoryFractionMinValue()
    { return GetMaxMemoryFractionMinValue_16(); }

  private native double GetMaxMemoryFractionMaxValue_17();
  public double GetMaxMemoryFractionMaxValue()
    { return GetMaxMemoryFractionMaxValue_17(); }

  private native double GetMaxMemoryFraction_18();
  public double GetMaxMemoryFraction()
    { return GetMaxMemoryFraction_18(); }

  private native void SetInterpolationMode_19(int id0);
  public void SetInterpolationMode(int id0)
    { SetInterpolationMode_19(id0); }

  private native int GetInterpolationModeMinValue_20();
  public int GetInterpolationModeMinValue()
    { return GetInterpolationModeMinValue_20(); }

  private native int GetInterpolationModeMaxValue_21();
  public int GetInterpolationModeMaxValue()
    { return GetInterpolationModeMaxValue_21(); }

  private native int GetInterpolationMode_22();
  public int GetInterpolationMode()
    { return GetInterpolationMode_22(); }

  private native void SetInterpolationModeToNearestNeighbor_23();
  public void SetInterpolationModeToNearestNeighbor()
    { SetInterpolationModeToNearestNeighbor_23(); }

  private native void SetInterpolationModeToLinear_24();
  public void SetInterpolationModeToLinear()
    { SetInterpolationModeToLinear_24(); }

  private native void SetInterpolationModeToCubic_25();
  public void SetInterpolationModeToCubic()
    { SetInterpolationModeToCubic_25(); }

  private native void CreateCanonicalView_26(vtkRenderer id0,vtkVolume id1,vtkVolume id2,vtkImageData id3,int id4,double id5[],double id6[]);
  public void CreateCanonicalView(vtkRenderer id0,vtkVolume id1,vtkVolume id2,vtkImageData id3,int id4,double id5[],double id6[])
    { CreateCanonicalView_26(id0,id1,id2,id3,id4,id5,id6); }

  private native void SetInteractiveUpdateRate_27(double id0);
  public void SetInteractiveUpdateRate(double id0)
    { SetInteractiveUpdateRate_27(id0); }

  private native double GetInteractiveUpdateRateMinValue_28();
  public double GetInteractiveUpdateRateMinValue()
    { return GetInteractiveUpdateRateMinValue_28(); }

  private native double GetInteractiveUpdateRateMaxValue_29();
  public double GetInteractiveUpdateRateMaxValue()
    { return GetInteractiveUpdateRateMaxValue_29(); }

  private native double GetInteractiveUpdateRate_30();
  public double GetInteractiveUpdateRate()
    { return GetInteractiveUpdateRate_30(); }

  private native void SetInteractiveAdjustSampleDistances_31(int id0);
  public void SetInteractiveAdjustSampleDistances(int id0)
    { SetInteractiveAdjustSampleDistances_31(id0); }

  private native int GetInteractiveAdjustSampleDistancesMinValue_32();
  public int GetInteractiveAdjustSampleDistancesMinValue()
    { return GetInteractiveAdjustSampleDistancesMinValue_32(); }

  private native int GetInteractiveAdjustSampleDistancesMaxValue_33();
  public int GetInteractiveAdjustSampleDistancesMaxValue()
    { return GetInteractiveAdjustSampleDistancesMaxValue_33(); }

  private native int GetInteractiveAdjustSampleDistances_34();
  public int GetInteractiveAdjustSampleDistances()
    { return GetInteractiveAdjustSampleDistances_34(); }

  private native void InteractiveAdjustSampleDistancesOn_35();
  public void InteractiveAdjustSampleDistancesOn()
    { InteractiveAdjustSampleDistancesOn_35(); }

  private native void InteractiveAdjustSampleDistancesOff_36();
  public void InteractiveAdjustSampleDistancesOff()
    { InteractiveAdjustSampleDistancesOff_36(); }

  private native void SetAutoAdjustSampleDistances_37(int id0);
  public void SetAutoAdjustSampleDistances(int id0)
    { SetAutoAdjustSampleDistances_37(id0); }

  private native int GetAutoAdjustSampleDistancesMinValue_38();
  public int GetAutoAdjustSampleDistancesMinValue()
    { return GetAutoAdjustSampleDistancesMinValue_38(); }

  private native int GetAutoAdjustSampleDistancesMaxValue_39();
  public int GetAutoAdjustSampleDistancesMaxValue()
    { return GetAutoAdjustSampleDistancesMaxValue_39(); }

  private native int GetAutoAdjustSampleDistances_40();
  public int GetAutoAdjustSampleDistances()
    { return GetAutoAdjustSampleDistances_40(); }

  private native void AutoAdjustSampleDistancesOn_41();
  public void AutoAdjustSampleDistancesOn()
    { AutoAdjustSampleDistancesOn_41(); }

  private native void AutoAdjustSampleDistancesOff_42();
  public void AutoAdjustSampleDistancesOff()
    { AutoAdjustSampleDistancesOff_42(); }

  private native void SetSampleDistance_43(double id0);
  public void SetSampleDistance(double id0)
    { SetSampleDistance_43(id0); }

  private native double GetSampleDistance_44();
  public double GetSampleDistance()
    { return GetSampleDistance_44(); }

  private native void Render_45(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_45(id0,id1); }

  private native void ReleaseGraphicsResources_46(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_46(id0); }

  private native void SetVectorMode_47(int id0);
  public void SetVectorMode(int id0)
    { SetVectorMode_47(id0); }

  private native int GetVectorModeMinValue_48();
  public int GetVectorModeMinValue()
    { return GetVectorModeMinValue_48(); }

  private native int GetVectorModeMaxValue_49();
  public int GetVectorModeMaxValue()
    { return GetVectorModeMaxValue_49(); }

  private native int GetVectorMode_50();
  public int GetVectorMode()
    { return GetVectorMode_50(); }

  private native void SetVectorComponent_51(int id0);
  public void SetVectorComponent(int id0)
    { SetVectorComponent_51(id0); }

  private native int GetVectorComponentMinValue_52();
  public int GetVectorComponentMinValue()
    { return GetVectorComponentMinValue_52(); }

  private native int GetVectorComponentMaxValue_53();
  public int GetVectorComponentMaxValue()
    { return GetVectorComponentMaxValue_53(); }

  private native int GetVectorComponent_54();
  public int GetVectorComponent()
    { return GetVectorComponent_54(); }

  public vtkSmartVolumeMapper() { super(); }

  public vtkSmartVolumeMapper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkSmartVolumeMapper.java <==
// java wrapper for vtkSmartVolumeMapper object
//

package vtk;
import vtk.*;

public class vtkSmartVolumeMapper extends vtkVolumeMapper
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFinalColorWindow_2(double id0);
  public void SetFinalColorWindow(double id0)
    { SetFinalColorWindow_2(id0); }

  private native double GetFinalColorWindow_3();
  public double GetFinalColorWindow()
    { return GetFinalColorWindow_3(); }

  private native void SetFinalColorLevel_4(double id0);
  public void SetFinalColorLevel(double id0)
    { SetFinalColorLevel_4(id0); }

  private native double GetFinalColorLevel_5();
  public double GetFinalColorLevel()
    { return GetFinalColorLevel_5(); }

  private native void SetRequestedRenderMode_6(int id0);
  public void SetRequestedRenderMode(int id0)
    { SetRequestedRenderMode_6(id0); }

  private native void SetRequestedRenderModeToDefault_7();
  public void SetRequestedRenderModeToDefault()
    { SetRequestedRenderModeToDefault_7(); }

  private native void SetRequestedRenderModeToRayCast_8();
  public void SetRequestedRenderModeToRayCast()
    { SetRequestedRenderModeToRayCast_8(); }

  private native void SetRequestedRenderModeToGPU_9();
  public void SetRequestedRenderModeToGPU()
    { SetRequestedRenderModeToGPU_9(); }

  private native void SetRequestedRenderModeToOSPRay_10();
  public void SetRequestedRenderModeToOSPRay()
    { SetRequestedRenderModeToOSPRay_10(); }

  private native int GetRequestedRenderMode_11();
  public int GetRequestedRenderMode()
    { return GetRequestedRenderMode_11(); }

  private native int GetLastUsedRenderMode_12();
  public int GetLastUsedRenderMode()
    { return GetLastUsedRenderMode_12(); }

  private native void SetMaxMemoryInBytes_13(int id0);
  public void SetMaxMemoryInBytes(int id0)
    { SetMaxMemoryInBytes_13(id0); }

  private native int GetMaxMemoryInBytes_14();
  public int GetMaxMemoryInBytes()
    { return GetMaxMemoryInBytes_14(); }

  private native void SetMaxMemoryFraction_15(double id0);
  public void SetMaxMemoryFraction(double id0)
    { SetMaxMemoryFraction_15(id0); }

  private native double GetMaxMemoryFractionMinValue_16();
  public double GetMaxMemoryFractionMinValue()
    { return GetMaxMemoryFractionMinValue_16(); }

  private native double GetMaxMemoryFractionMaxValue_17();
  public double GetMaxMemoryFractionMaxValue()
    { return GetMaxMemoryFractionMaxValue_17(); }

  private native double GetMaxMemoryFraction_18();
  public double GetMaxMemoryFraction()
    { return GetMaxMemoryFraction_18(); }

  private native void SetInterpolationMode_19(int id0);
  public void SetInterpolationMode(int id0)
    { SetInterpolationMode_19(id0); }

  private native int GetInterpolationModeMinValue_20();
  public int GetInterpolationModeMinValue()
    { return GetInterpolationModeMinValue_20(); }

  private native int GetInterpolationModeMaxValue_21();
  public int GetInterpolationModeMaxValue()
    { return GetInterpolationModeMaxValue_21(); }

  private native int GetInterpolationMode_22();
  public int GetInterpolationMode()
    { return GetInterpolationMode_22(); }

  private native void SetInterpolationModeToNearestNeighbor_23();
  public void SetInterpolationModeToNearestNeighbor()
    { SetInterpolationModeToNearestNeighbor_23(); }

  private native void SetInterpolationModeToLinear_24();
  public void SetInterpolationModeToLinear()
    { SetInterpolationModeToLinear_24(); }

  private native void SetInterpolationModeToCubic_25();
  public void SetInterpolationModeToCubic()
    { SetInterpolationModeToCubic_25(); }

  private native void CreateCanonicalView_26(vtkRenderer id0,vtkVolume id1,vtkVolume id2,vtkImageData id3,int id4,double id5[],double id6[]);
  public void CreateCanonicalView(vtkRenderer id0,vtkVolume id1,vtkVolume id2,vtkImageData id3,int id4,double id5[],double id6[])
    { CreateCanonicalView_26(id0,id1,id2,id3,id4,id5,id6); }

  private native void SetInteractiveUpdateRate_27(double id0);
  public void SetInteractiveUpdateRate(double id0)
    { SetInteractiveUpdateRate_27(id0); }

  private native double GetInteractiveUpdateRateMinValue_28();
  public double GetInteractiveUpdateRateMinValue()
    { return GetInteractiveUpdateRateMinValue_28(); }

  private native double GetInteractiveUpdateRateMaxValue_29();
  public double GetInteractiveUpdateRateMaxValue()
    { return GetInteractiveUpdateRateMaxValue_29(); }

  private native double GetInteractiveUpdateRate_30();
  public double GetInteractiveUpdateRate()
    { return GetInteractiveUpdateRate_30(); }

  private native void SetInteractiveAdjustSampleDistances_31(int id0);
  public void SetInteractiveAdjustSampleDistances(int id0)
    { SetInteractiveAdjustSampleDistances_31(id0); }

  private native int GetInteractiveAdjustSampleDistancesMinValue_32();
  public int GetInteractiveAdjustSampleDistancesMinValue()
    { return GetInteractiveAdjustSampleDistancesMinValue_32(); }

  private native int GetInteractiveAdjustSampleDistancesMaxValue_33();
  public int GetInteractiveAdjustSampleDistancesMaxValue()
    { return GetInteractiveAdjustSampleDistancesMaxValue_33(); }

  private native int GetInteractiveAdjustSampleDistances_34();
  public int GetInteractiveAdjustSampleDistances()
    { return GetInteractiveAdjustSampleDistances_34(); }

  private native void InteractiveAdjustSampleDistancesOn_35();
  public void InteractiveAdjustSampleDistancesOn()
    { InteractiveAdjustSampleDistancesOn_35(); }

  private native void InteractiveAdjustSampleDistancesOff_36();
  public void InteractiveAdjustSampleDistancesOff()
    { InteractiveAdjustSampleDistancesOff_36(); }

  private native void SetAutoAdjustSampleDistances_37(int id0);
  public void SetAutoAdjustSampleDistances(int id0)
    { SetAutoAdjustSampleDistances_37(id0); }

  private native int GetAutoAdjustSampleDistancesMinValue_38();
  public int GetAutoAdjustSampleDistancesMinValue()
    { return GetAutoAdjustSampleDistancesMinValue_38(); }

  private native int GetAutoAdjustSampleDistancesMaxValue_39();
  public int GetAutoAdjustSampleDistancesMaxValue()
    { return GetAutoAdjustSampleDistancesMaxValue_39(); }

  private native int GetAutoAdjustSampleDistances_40();
  public int GetAutoAdjustSampleDistances()
    { return GetAutoAdjustSampleDistances_40(); }

  private native void AutoAdjustSampleDistancesOn_41();
  public void AutoAdjustSampleDistancesOn()
    { AutoAdjustSampleDistancesOn_41(); }

  private native void AutoAdjustSampleDistancesOff_42();
  public void AutoAdjustSampleDistancesOff()
    { AutoAdjustSampleDistancesOff_42(); }

  private native void SetSampleDistance_43(double id0);
  public void SetSampleDistance(double id0)
    { SetSampleDistance_43(id0); }

  private native double GetSampleDistance_44();
  public double GetSampleDistance()
    { return GetSampleDistance_44(); }

  private native void Render_45(vtkRenderer id0,vtkVolume id1);
  public void Render(vtkRenderer id0,vtkVolume id1)
    { Render_45(id0,id1); }

  private native void ReleaseGraphicsResources_46(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_46(id0); }

  private native void SetVectorMode_47(int id0);
  public void SetVectorMode(int id0)
    { SetVectorMode_47(id0); }

  private native int GetVectorMode_48();
  public int GetVectorMode()
    { return GetVectorMode_48(); }

  private native void SetVectorComponent_49(int id0);
  public void SetVectorComponent(int id0)
    { SetVectorComponent_49(id0); }

  private native int GetVectorComponentMinValue_50();
  public int GetVectorComponentMinValue()
    { return GetVectorComponentMinValue_50(); }

  private native int GetVectorComponentMaxValue_51();
  public int GetVectorComponentMaxValue()
    { return GetVectorComponentMaxValue_51(); }

  private native int GetVectorComponent_52();
  public int GetVectorComponent()
    { return GetVectorComponent_52(); }

  public vtkSmartVolumeMapper() { super(); }

  public vtkSmartVolumeMapper(long id) { super(id); }
  public native long   VTKInit();

}
